@@ -66,7 +66,7 @@
 
 #define ANJUTA_PIXMAP_PASSWORD "password.png"
 #define FILE_BUFFER_SIZE 1024
-#define FILE_INPUT_BUFFER_SIZE		1048576
+#define FILE_INPUT_BUFFER_SIZE  (1024 * 1024 * 4)
 #ifndef __MAX_BAUD
 #  if defined(B460800)
 #    define __MAX_BAUD B460800
@@ -422,11 +422,12 @@ anjuta_launcher_send_stdin_eof (AnjutaLauncher *launcher)
 void
 anjuta_launcher_send_ptyin (AnjutaLauncher *launcher, const gchar * input_str)
 {
-	gsize bytes_written;
+	gsize bytes_written = 0;
 	GError *err = NULL;
 	
 	g_return_if_fail (launcher);
 	g_return_if_fail (input_str);
+	g_return_if_fail (launcher->priv->pty_channel != NULL);
 	
 	if (strlen (input_str) == 0) 
 		return;
@@ -965,9 +966,23 @@ anjuta_launcher_execution_done_cleanup (AnjutaLauncher *launcher,
 	if (launcher->priv->pty_output_buffer)
 		g_free (launcher->priv->pty_output_buffer);
 	if (launcher->priv->stdout_buffer)
+	{
+		/* Send remaining data if last line is not terminated with EOL */
+		(launcher->priv->output_callback)(launcher,
+			       ANJUTA_LAUNCHER_OUTPUT_STDOUT,
+			       launcher->priv->stdout_buffer,
+			       launcher->priv->callback_data);
 		g_free (launcher->priv->stdout_buffer);
+	}
 	if (launcher->priv->stderr_buffer)
+	{
+		/* Send remaining data if last line is not terminated with EOL */
+		(launcher->priv->output_callback)(launcher,
+			       ANJUTA_LAUNCHER_OUTPUT_STDERR,
+			       launcher->priv->stderr_buffer,
+			       launcher->priv->callback_data);
 		g_free (launcher->priv->stdout_buffer);
+	}
 	
 	/* Save them before we re-initialize */
 	child_status = launcher->priv->child_status;
@@ -1125,7 +1140,8 @@ anjuta_launcher_fork (AnjutaLauncher *launcher, const gchar *dir, gchar *const a
 		/* Set working directory */
 		if (dir != NULL)
 		{
-			chdir (dir);
+			/* Exit if working directory doesn't exist */
+			if (chdir (dir) != 0) _exit(-1);
 		}
 
 		/* Set up environment */
