@@ -23,16 +23,14 @@
 
 #include <config.h>
 #include <libanjuta/anjuta-shell.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/anjuta-debug.h>
-
 #include "plugin.h"
 #include "class-inherit.h"
 
-#define ICON_FILE "class-inheritance.png"
+#define ICON_FILE "anjuta-class-inheritance-plugin-48.png"
 
 static gpointer parent_class;
 
@@ -48,7 +46,7 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	
 	if (root_uri)
 	{
-		gchar *root_dir = gnome_vfs_get_local_path_from_uri (root_uri);
+		gchar *root_dir = anjuta_util_get_local_path_from_uri (root_uri);
 		if (root_dir)
 		{	
 			ci_plugin->top_dir = g_strdup(root_dir);
@@ -61,7 +59,7 @@ project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		ci_plugin->top_dir = NULL;
 	
 	/* let's update the graph */
-	class_inheritance_update_graph (ci_plugin);
+	cls_inherit_update (ci_plugin);
 }
 
 static void
@@ -72,10 +70,7 @@ project_root_removed (AnjutaPlugin *plugin, const gchar *name,
 	ci_plugin = ANJUTA_PLUGIN_CLASS_INHERITANCE (plugin);
 	
 	/* clean up the canvas */
-	class_inheritance_clean_canvas (ci_plugin);
-
-	/* destroy and re-initialize the hashtable */
-	class_inheritance_hash_table_clear	(ci_plugin);
+	cls_inherit_clear (ci_plugin);
 	
 	if (ci_plugin->top_dir)
 		g_free(ci_plugin->top_dir);
@@ -100,26 +95,26 @@ register_stock_icons (AnjutaPlugin *plugin)
 static gboolean
 activate_plugin (AnjutaPlugin *plugin)
 {
-	AnjutaClassInheritance *class_inheritance;
+	AnjutaClassInheritance *cls_inherit;
 	static gboolean initialized = FALSE;
 	
-	DEBUG_PRINT ("AnjutaClassInheritance: Activating plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaClassInheritance: Activating plugin ...");
 	
 	register_stock_icons (plugin);
 	
-	class_inheritance = ANJUTA_PLUGIN_CLASS_INHERITANCE (plugin);
+	cls_inherit = ANJUTA_PLUGIN_CLASS_INHERITANCE (plugin);
 	
-	class_inheritance_base_gui_init (class_inheritance);
+	cls_inherit_init (cls_inherit);
 	
-	anjuta_shell_add_widget (plugin->shell, class_inheritance->widget,
+	anjuta_shell_add_widget (plugin->shell, cls_inherit->widget,
 							 "AnjutaClassInheritance", _("Inheritance Graph"),
 							 "class-inheritance-plugin-icon",
 							 ANJUTA_SHELL_PLACEMENT_CENTER, NULL);
-	class_inheritance->top_dir = NULL;
+	cls_inherit->top_dir = NULL;
 	
 	/* set up project directory watch */
-	class_inheritance->root_watch_id = anjuta_plugin_add_watch (plugin,
-									"project_root_uri",
+	cls_inherit->root_watch_id = anjuta_plugin_add_watch (plugin,
+									IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI,
 									project_root_added,
 									project_root_removed, NULL);
 
@@ -130,18 +125,12 @@ activate_plugin (AnjutaPlugin *plugin)
 static gboolean
 deactivate_plugin (AnjutaPlugin *plugin)
 {
-	DEBUG_PRINT ("AnjutaClassInheritance: Dectivating plugin ...");
+	DEBUG_PRINT ("%s", "AnjutaClassInheritance: Dectivating plugin ...");
 	AnjutaClassInheritance* class_inheritance;
 	class_inheritance = ANJUTA_PLUGIN_CLASS_INHERITANCE (plugin);
 
 	/* clean up the canvas [e.g. destroys it's elements */
-	class_inheritance_clean_canvas (class_inheritance);
-	
-	/* destroy the nodestatus hash table */
-	if (class_inheritance->expansion_node_list) {
-		g_hash_table_destroy (class_inheritance->expansion_node_list);
-		class_inheritance->expansion_node_list = NULL;
-	}
+	cls_inherit_free (class_inheritance);
 	
 	/* Container holds the last ref to this widget so it will be destroyed as
 	 * soon as removed. No need to separately destroy it. */
@@ -169,14 +158,14 @@ class_inheritance_finalize (GObject *obj)
 		g_free (ci_plugin->top_dir);
 	
 	/* Finalization codes here */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (obj));
+	G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
 class_inheritance_dispose (GObject *obj)
 {
 	/* Disposition codes */
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, dispose, (obj));
+	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
 static void
@@ -189,7 +178,6 @@ class_inheritance_instance_init (GObject *obj)
 	plugin->widget = NULL;
 	plugin->graph = NULL;
 	plugin->gvc = NULL;
-	plugin->expansion_node_list = NULL;
 }
 
 static void
