@@ -40,7 +40,6 @@
 #include <libanjuta/interfaces/ianjuta-editor-assist.h>
 #include <libanjuta/interfaces/ianjuta-file-savable.h>
 #include <libanjuta/interfaces/ianjuta-editor-language.h>
-#include <libanjuta/interfaces/ianjuta-language-support.h>
 #include <libanjuta/interfaces/ianjuta-language.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
 #include <libanjuta/interfaces/ianjuta-document.h>
@@ -161,6 +160,9 @@ static GtkActionEntry actions_file[] = {
   { "ActionFileCloseAll", GTK_STOCK_CLOSE, N_("Close All"), "<shift><control>w",
 	N_("Close all files"),
     G_CALLBACK (on_close_all_file_activate)},
+  { "ActionFileCloseOther", GTK_STOCK_CLOSE, N_("Close Other"), "<shift><control>o",
+	N_("Close other documents"),
+    G_CALLBACK (on_close_other_file_activate)},	
   { "ActionFileReload", GTK_STOCK_REVERT_TO_SAVED, N_("Reload F_ile"), NULL,
 	N_("Reload current file"),
     G_CALLBACK (on_reload_file_activate)},
@@ -435,6 +437,10 @@ static struct ActionToggleGroupInfo action_toggle_groups[] = {
 
 #define MAX_TITLE_LENGTH 80
 
+static void
+on_editor_lang_changed (IAnjutaEditor* editor, const gchar* language,
+                        DocmanPlugin* plugin);
+
 static gchar* 
 get_directory_display_name (DocmanPlugin* plugin,
 							GFile* file)
@@ -1064,44 +1070,6 @@ create_highlight_submenu (DocmanPlugin *plugin, IAnjutaEditor *editor)
 	return submenu;
 }
 
-static void
-on_document_added (AnjutaDocman *docman, IAnjutaDocument *doc,
-				   AnjutaPlugin *plugin)
-{
-	GtkWidget *highlight_submenu, *highlight_menu;
-	DocmanPlugin *docman_plugin;
-	
-	docman_plugin = ANJUTA_PLUGIN_DOCMAN (plugin);
-	g_signal_connect (G_OBJECT (doc), "update_ui",
-					  G_CALLBACK (on_document_update_ui),
-					  docman_plugin);
-	g_signal_connect (G_OBJECT (doc), "update-save-ui",
-					  G_CALLBACK (on_document_update_save_ui),
-					  plugin);
-	/* Present the vbox as this is the widget that was added to the shell */
-	anjuta_shell_present_widget (plugin->shell,
-								 GTK_WIDGET (docman_plugin->vbox), NULL);
-
-	if (IANJUTA_IS_EDITOR (doc))
-	{
-		IAnjutaEditor *te;
-
-		te = IANJUTA_EDITOR (doc);
-	
-		/* Create Highlight submenu */
-		highlight_submenu = 
-			create_highlight_submenu (docman_plugin, te);
-		if (highlight_submenu)
-		{
-			highlight_menu =
-				gtk_ui_manager_get_widget (GTK_UI_MANAGER (docman_plugin->ui),
-						"/MenuMain/MenuView/MenuViewEditor/MenuFormatStyle");
-			gtk_menu_item_set_submenu (GTK_MENU_ITEM (highlight_menu),
-									   highlight_submenu);
-		}
-	}
-}
-
 static void
 on_support_plugin_deactivated (AnjutaPlugin* plugin, DocmanPlugin* docman_plugin)
 {
@@ -1149,13 +1117,97 @@ unload_unused_support_plugins (DocmanPlugin* docman_plugin,
 	g_list_free (plugins);
 }
 
+static void
+update_language_plugin (AnjutaDocman *docman, IAnjutaDocument *doc,
+                        AnjutaPlugin *plugin)
+{
+	if (IANJUTA_IS_EDITOR_LANGUAGE (doc))
+	{
+		DEBUG_PRINT("%s", "Beginning language support");
+		AnjutaPluginManager *plugin_manager;
+		DocmanPlugin* docman_plugin = ANJUTA_PLUGIN_DOCMAN (plugin);
+		IAnjutaLanguage *lang_manager;
+		GList *new_support_plugins, *support_plugin_descs, *needed_plugins, *node;
+		const gchar *language;
+
+		g_signal_handlers_block_by_func (doc, on_editor_lang_changed, plugin);
+		
+		lang_manager = anjuta_shell_get_interface (plugin->shell,
+		                                           IAnjutaLanguage,
+		                                           NULL);
+		if (!lang_manager)
+		{
+			g_warning ("Could not load language manager!");
+			return;
+		}
+		language = ianjuta_language_get_name_from_editor (lang_manager,
+		                                                  IANJUTA_EDITOR_LANGUAGE (doc),
+		                                                  NULL);
+		if (!language)
+		{
+			DEBUG_PRINT ("%s", "Unloading all language support plugins");
+			/* Unload all language support plugins */
+			/* Copy the list because the "deactivate"-signal handler modifies
+			 * the original list */
+			GList* plugins = g_list_copy (docman_plugin->support_plugins);
+			g_list_foreach (plugins, (GFunc) anjuta_plugin_deactivate, NULL);
+			g_list_free (plugins);
+			return;
+		}
+
+		/* Load current language editor support plugins */
+		plugin_manager = anjuta_shell_get_plugin_manager (plugin->shell, NULL);
+		support_plugin_descs = anjuta_plugin_manager_query (plugin_manager,
+		                                                    "Anjuta Plugin",
+		                                                    "Interfaces",
+		                                                    "IAnjutaLanguageSupport",
+		                                                    "Language Support",
+		                                                    "Languages",
+		                                                    language, NULL);
+		new_support_plugins = NULL;
+		for (node = support_plugin_descs; node != NULL; node = g_list_next (node))
+		{
+			gchar *plugin_id;
+
+			AnjutaPluginDescription *desc = node->data;
+
+			anjuta_plugin_description_get_string (desc, "Anjuta Plugin", "Location",
+			                                      &plugin_id);
+
+			new_support_plugins = g_list_append (new_support_plugins, plugin_id);
+		}
+		g_list_free (support_plugin_descs);
+
+		/* Load new plugins */
+		needed_plugins = 
+			load_new_support_plugins (docman_plugin, new_support_plugins,
+			                          plugin_manager);			
+
+		/* Unload unused plugins */
+		unload_unused_support_plugins (docman_plugin, needed_plugins);
+
+		/* Update list */
+		g_list_free (docman_plugin->support_plugins);
+		docman_plugin->support_plugins = needed_plugins;
+
+		if (new_support_plugins)
+		{
+			g_list_foreach (new_support_plugins, (GFunc) g_free, NULL);
+			g_list_free (new_support_plugins);
+		}
+
+		g_signal_handlers_unblock_by_func (doc, on_editor_lang_changed, plugin);
+	}				 
+}
+
 static void
 on_document_changed (AnjutaDocman *docman, IAnjutaDocument *doc,
 					 AnjutaPlugin *plugin)
 {
 	DocmanPlugin *docman_plugin;
 	update_document_ui (plugin, doc);
-	
+
+	docman_plugin = ANJUTA_PLUGIN_DOCMAN (plugin);
 	if (doc)
 	{
 		GValue value = {0, };
@@ -1171,91 +1223,74 @@ on_document_changed (AnjutaDocman *docman, IAnjutaDocument *doc,
 		anjuta_shell_remove_value (plugin->shell, IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
 								   NULL);
 	}
-	docman_plugin = ANJUTA_PLUGIN_DOCMAN (plugin);
+	
 	
 	if (doc && IANJUTA_IS_EDITOR (doc))
 	{
 		update_status (docman_plugin, IANJUTA_EDITOR (doc));
-
-		if (IANJUTA_IS_EDITOR_LANGUAGE (doc))
-		{
-			DEBUG_PRINT("%s", "Beginning language support");
-			AnjutaPluginManager *plugin_manager;
-			IAnjutaLanguage *lang_manager;
-			GList *new_support_plugins, *support_plugin_descs, *needed_plugins, *node;
-			const gchar *language;
-	
-			lang_manager = anjuta_shell_get_interface (plugin->shell,
-														IAnjutaLanguage,
-														NULL);
-			if (!lang_manager)
-			{
-				g_warning ("Could not load language manager!");
-				goto out;
-			}
-			language = ianjuta_language_get_name_from_editor (lang_manager,
-															  IANJUTA_EDITOR_LANGUAGE (doc),
-															  NULL);
-			if (!language)
-			{
-				DEBUG_PRINT ("%s", "Unloading all language support plugins");
-				/* Unload all language support plugins */
-				/* Copy the list because the "deactivate"-signal handler modifies
-				 * the original list */
-				GList* plugins = g_list_copy (docman_plugin->support_plugins);
-				g_list_foreach (plugins, (GFunc) anjuta_plugin_deactivate, NULL);
-				g_list_free (plugins);
-				goto out;
-			}
-
-			/* Load current language editor support plugins */
-			plugin_manager = anjuta_shell_get_plugin_manager (plugin->shell, NULL);
-			support_plugin_descs = anjuta_plugin_manager_query (plugin_manager,
-																"Anjuta Plugin",
-																"Interfaces",
-																"IAnjutaLanguageSupport",
-																"Language Support",
-																"Languages",
-																language, NULL);
-			new_support_plugins = NULL;
-			for (node = support_plugin_descs; node != NULL; node = g_list_next (node))
-			{
-				gchar *plugin_id;
-				
-				AnjutaPluginDescription *desc = node->data;
-				
-				anjuta_plugin_description_get_string (desc, "Anjuta Plugin", "Location",
-													  &plugin_id);
-				
-				new_support_plugins = g_list_append (new_support_plugins, plugin_id);
-			}
-			g_list_free (support_plugin_descs);
-			
-			/* Load new plugins */
-			needed_plugins = 
-				load_new_support_plugins (docman_plugin, new_support_plugins,
-										  plugin_manager);			
-			
-			/* Unload unused plugins */
-			unload_unused_support_plugins (docman_plugin, needed_plugins);
-			
-			/* Update list */
-			g_list_free (docman_plugin->support_plugins);
-			docman_plugin->support_plugins = needed_plugins;
-			
-			if (new_support_plugins)
-			{
-				g_list_foreach (new_support_plugins, (GFunc) g_free, NULL);
-				g_list_free (new_support_plugins);
-			}
-		}
+		update_language_plugin (docman, doc, plugin);
 	}
 	else
 		update_status (docman_plugin, NULL);
-out:
+
 	update_title (ANJUTA_PLUGIN_DOCMAN (plugin));
 }
 
+static void
+on_editor_lang_changed (IAnjutaEditor* editor,
+                        const gchar* language,
+                        DocmanPlugin* plugin)
+{
+	update_language_plugin (ANJUTA_DOCMAN (plugin->docman),
+	                        IANJUTA_DOCUMENT (editor),
+	                        ANJUTA_PLUGIN(plugin));
+}
+
+static void
+on_document_added (AnjutaDocman *docman, IAnjutaDocument *doc,
+				   AnjutaPlugin *plugin)
+{
+	GtkWidget *highlight_submenu, *highlight_menu;
+	DocmanPlugin *docman_plugin;
+	
+	docman_plugin = ANJUTA_PLUGIN_DOCMAN (plugin);
+	g_signal_connect (G_OBJECT (doc), "update_ui",
+					  G_CALLBACK (on_document_update_ui),
+					  docman_plugin);
+	g_signal_connect (G_OBJECT (doc), "update-save-ui",
+					  G_CALLBACK (on_document_update_save_ui),
+					  plugin);
+	
+	/* Present the vbox as this is the widget that was added to the shell */
+	anjuta_shell_present_widget (plugin->shell,
+								 GTK_WIDGET (docman_plugin->vbox), NULL);
+
+	if (IANJUTA_IS_EDITOR (doc))
+	{
+		IAnjutaEditor *te;
+
+		te = IANJUTA_EDITOR (doc);
+
+		/* Check for language changes */
+		g_signal_connect (G_OBJECT (doc), "language-changed",
+		                  G_CALLBACK (on_editor_lang_changed),
+		                  docman_plugin);
+		                              
+		
+		/* Create Highlight submenu */
+		highlight_submenu = 
+			create_highlight_submenu (docman_plugin, te);
+		if (highlight_submenu)
+		{
+			highlight_menu =
+				gtk_ui_manager_get_widget (GTK_UI_MANAGER (docman_plugin->ui),
+						"/MenuMain/MenuView/MenuViewEditor/MenuFormatStyle");
+			gtk_menu_item_set_submenu (GTK_MENU_ITEM (highlight_menu),
+									   highlight_submenu);
+		}
+	}
+}
+
 static gboolean
 on_window_key_press_event (AnjutaShell *shell,
 						   GdkEventKey *event,
@@ -1472,7 +1507,7 @@ static void
 docman_plugin_set_tab_pos (DocmanPlugin *ep)
 {
 	if (anjuta_preferences_get_bool_with_default (ep->prefs, EDITOR_TABS_HIDE,
-												 TRUE))
+												 FALSE))
 	{
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK (ep->docman), FALSE);
 	}
@@ -1622,8 +1657,8 @@ on_notify_timer (AnjutaPreferences* prefs,
 #define REGISTER_NOTIFY(key, func, type) \
 	notify_id = anjuta_preferences_notify_add_##type (ep->prefs, \
 											   key, func, ep, NULL); \
-	ep->gconf_notify_ids = g_list_prepend (ep->gconf_notify_ids, \
-										   GUINT_TO_POINTER (notify_id));
+	ep->notify_ids = g_list_prepend (ep->notify_ids, \
+								     GUINT_TO_POINTER (notify_id));
 static void
 prefs_init (DocmanPlugin *ep)
 {
@@ -1641,15 +1676,15 @@ static void
 prefs_finalize (DocmanPlugin *ep)
 {
 	GList *node;
-	node = ep->gconf_notify_ids;
+	node = ep->notify_ids;
 	while (node)
 	{
 		anjuta_preferences_notify_remove (ep->prefs,
 										  GPOINTER_TO_UINT (node->data));
 		node = g_list_next (node);
 	}
-	g_list_free (ep->gconf_notify_ids);
-	ep->gconf_notify_ids = NULL;
+	g_list_free (ep->notify_ids);
+	ep->notify_ids = NULL;
 }
 
 static gboolean
@@ -1859,7 +1894,7 @@ docman_plugin_instance_init (GObject *obj)
 	DocmanPlugin *plugin = ANJUTA_PLUGIN_DOCMAN (obj);
 	plugin->uiid = 0;
 	plugin->g_tabbing = FALSE;
-	plugin->gconf_notify_ids = NULL;
+	plugin->notify_ids = NULL;
 	plugin->support_plugins = NULL;
 }
 
